# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%{!?python_sitearch: %define python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{?!pybasever:%{expand:%%define pybasever %(python -c "import sys ; print sys.version[:3]")}}

Summary:	Library providing the Gnome XSLT engine
Name:		libxslt
Version:	1.1.28
Release:	6.0.cf.%{__distinit}%{__distvers}
License:	MIT
Group:		Development/Libraries
URL:		http://xmlsoft.org/XSLT/
Source:		ftp://xmlsoft.org/XSLT/libxslt-%{version}.tar.gz
Patch0:		multilib.patch
Patch1:		libxslt-1.1.27-utf8-docs.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
Requires:	libxml2 >= 2.6.27
BuildRequires:	libxml2-devel >= 2.6.27
BuildRequires:	python2-devel >= 2.3, libxml2-python, libgcrypt-devel

# Filter provide for python binding shared object
%global __provides_exclude ^libxsltmod.so(\\(\\)\\(64bit\\))?$

%description
This C library allows to transform XML files into other XML files (or HTML,
text, ...) using the standard XSLT stylesheet transformation mechanism. The
xsltproc command is a command line interface to the XSLT engine

%package devel
Summary:	Libraries, includes, etc. to embed the Gnome XSLT engine
Group:		Development/Libraries
Requires:	libxslt = %{version}-%{release}
Requires:	libxml2-devel >= 2.6.27
Requires:	libgcrypt-devel
# From Fedora 11, RHEL-6, pkgconfig dependency is auto-detected
%if 0%{?fedora} < 11 && 0%{?rhel} < 6
Requires:	pkgconfig
%endif
# From Fedora 14, %%{_datadir}/aclocal is included in the filesystem package
%if 0%{?fedora} < 14
Requires:	%{_datadir}/aclocal
%endif

%description devel
The libxslt-devel package contains libraries and header files for developing
applications that use libxslt.

%package python
Summary:	Python bindings for the libxslt library
Group:		Development/Libraries
Requires:	libxslt = %{version}-%{release}
Requires:	libxml2-python >= 2.6.27
%if "%{pybasever}" == "2.3"
Requires:	python-abi = 2.3
%endif

%description python
The libxslt-python package contains a module that permits applications written
in the Python programming language to use the interface supplied by the
libxslt library to apply XSLT transformations.

This library allows to parse stylesheets, uses the libxml2-python to load and
save XML and HTML files. Direct access to XPath and the XSLT transformation
context are possible to extend the XSLT language with XPath functions written
in Python.

%prep
%setup -q

# Fix multilib issues
%patch0 -p1

# Recode docs as UTF-8
# Note: tutorial2/libxslt_pipes.xml is explicitly iso-8859-2 encoded
%patch1 -b .utf8
# Now fix up the timestamps of patched docs files
touch -r ChangeLog.utf8 ChangeLog
touch -r NEWS.utf8 NEWS

# Exec permissions not needed on python scripts
chmod -c -x python/tests/*.py

%build
%configure --disable-static
make %{?_smp_mflags} V=1

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} INSTALL="install -p" install

# Remove files we don't want packaged
rm -f %{buildroot}%{_libdir}/*.la %{buildroot}%{python_sitearch}/libxsltmod.la
# TODO is empty
rm -f %{buildroot}%{_docdir}/libxslt-python-%{version}/TODO
# rpm 4.9 doesn't remove docs automatically, and we're specifying these manually
rm -rf %{buildroot}%{_docdir}/libxslt-%{version}/
rm -rf %{buildroot}%{_docdir}/libxslt-python-%{version}/

# Multiarch crazyness on timestamp differences
touch -m --reference=%{buildroot}%{_includedir}/libxslt/xslt.h \
	%{buildroot}%{_bindir}/xslt-config

%check
make tests

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog NEWS README Copyright FEATURES
%{_bindir}/xsltproc
%{_libdir}/libexslt.so.*
%{_libdir}/libxslt.so.*
%{_libdir}/libxslt-plugins
%{_mandir}/man1/xsltproc.1*

%files devel
%defattr(-,root,root,-)
%doc doc/*.html doc/html/ doc/*.gif doc/*.png
%doc doc/EXSLT doc/images/ doc/tutorial/ doc/tutorial2/
%doc doc/libxslt-api.xml
%doc doc/libxslt-refs.xml
%{_bindir}/xslt-config
%{_datadir}/aclocal/libxslt.m4
%{_includedir}/libexslt/
%{_includedir}/libxslt/
%{_libdir}/libexslt.so
%{_libdir}/libxslt.so
%{_libdir}/xsltConf.sh
%{_libdir}/pkgconfig/libxslt.pc
%{_libdir}/pkgconfig/libexslt.pc
%{_mandir}/man3/libxslt.3*
%{_mandir}/man3/libexslt.3*

%files python
%defattr(-,root,root,-)
%doc python/libxsltclass.txt
%doc python/tests/*.py
%doc python/tests/*.xml
%doc python/tests/*.xsl
%{python_sitearch}/libxslt.py*
%{python_sitearch}/libxsltmod.so

%changelog
* Mon Mar  3 2014 Paul Howarth <paul@city-fan.org> 1.1.28-6.0.cf
- Rebuild for libgcrypt 1.6.x in Rawhide

* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> 1.1.28-5.0.cf
- Avoid duplicate packaging of python examples

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> 1.1.28-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jun 23 2013 Paul Howarth <paul@city-fan.org> 1.1.28-3.0.cf
- Lots of API docs were in the main package rather than the devel package

* Sat Feb 23 2013 Paul Howarth <paul@city-fan.org> 1.1.28-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Nov 22 2012 Paul Howarth <paul@city-fan.org> 1.1.28-1.0.cf
- Update to 1.1.28
  Portability:
  - Fix python build by using libxsltmod_la_CPPFLAGS instead of AM_CPPFLAGS
  - configure should be more careful with linker script
  - Add gcrypt library in LIBADD, not LDFLAGS, as recommended
  Bug fixes:
  - Fix generate-id() to avoid generating the same ID
  - Fix crash with empty xsl:key/@match attribute
  - Fix crash when passing an uninitialized variable to document()
  - Add missing test docs to EXTRA_DIST
  - Fix regression: Default namespace not correctly used
  Cleanups:
  - Remove xsltTransStorageAdd and xsltTransStorageRemove from symbols.xml
  - autogen.sh cleanup
  - Consistent use of xslt processor
  - Add object files in tests/plugins to .gitignore
  - Fix error on bug-165 regression test
  - Remove xsltTransStorageAdd and xsltTransStorageRemove
- Drop patch for Gnome Bug #684564, now in upstream release
- Do build in verbose mode so we can see the compiler flags

* Wed Oct 10 2012 Paul Howarth <paul@city-fan.org> 1.1.27-2.0.cf
- Fix a regression in default namespace handling (Gnome Bug #684564)

* Wed Sep 12 2012 Paul Howarth <paul@city-fan.org> 1.1.27-1.0.cf
- Update to 1.1.27 (lots of bug-fixes and improvements)
- Update UTF8 patch

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> 1.1.26-10.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Aug  6 2011 Paul Howarth <paul@city-fan.org> 1.1.26-9.0.cf
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux
- Don't package python binding's empty TODO file
- Remove doubly-packaged python docs with rpm 4.9

* Mon Mar 21 2011 Paul Howarth <paul@city-fan.org> 1.1.26-8.0.cf
- ChangeLog: fix character encoding
- Restore timestamps for patched documentation files
- Filter provide for python binding shared object (rpm 4.9 onwards)

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> 1.1.26-7.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Dec 19 2010 Paul Howarth <paul@city-fan.org> 1.1.26-6.0.cf
- Resync with Rawhide again

* Thu Oct 28 2010 Paul Howarth <paul@city-fan.org> 1.1.26-5.0.cf
- Renumber patches to match Rawhide build

* Fri Oct 22 2010 Paul Howarth <paul@city-fan.org> 1.1.26-4.0.cf
- Drop redundant dependencies
- Maintain timestamps where possible

* Wed Jul 28 2010 Paul Howarth <paul@city-fan.org> 1.1.26-3.1.cf
- Rebuild for python 2.7 in Rawhide

* Tue May 25 2010 Paul Howarth <paul@city-fan.org> 1.1.26-3.0.cf
- Drop %%{_datadir}/aclocal dependency from devel package from Fedora 14,
  where this directory is part of the filesystem package (#533962)
- Drop manual pkgconfig dependency from devel package from Fedora 11, where
  this dependency is auto-detected
- Fix dist tag for RHEL-6 Beta

* Thu Feb 25 2010 Paul Howarth <paul@city-fan.org> 1.1.26-2.0.cf
- Dist tag for Rawhide no longer needs special-casing

* Fri Sep 25 2009 Paul Howarth <paul@city-fan.org> 1.1.26-1.0.cf
- Release of 1.1.26 (see NEWS for details)
- Patch for locking bug upstreamed
- Run the test suite in %%check

* Mon Sep 21 2009 Paul Howarth <paul@city-fan.org> 1.1.25-2.0.cf
- Fix a locking bug in 1.1.25
- Include extra docs, drop empty python TODO

* Thu Sep 17 2009 Daniel Veillard <veillard@redhat.com> 1.1.25-1
- Release of 1.1.25
  - add API versioning for libxslt shared library
  - xsl:sort lang support using the locale
  - many bug fixes

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> 1.1.24-4.0.cf
- Import from Fedora
- Don't build static libraries
- Clean up spec
- Recode ChangeLog and NEWS as UTF-8

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1.1.24-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> 1.1.24-3
- Rebuild for Python 2.6

* Wed Oct  8 2008 Daniel Veillard <veillard@redhat.com> 1.1.24-2.fc10
- CVE-2008-2935 fix

* Tue May 13 2008 Daniel Veillard <veillard@redhat.com> 1.1.24-1.fc10
- release of 1.1.24
- fixes a few bugs including the key initialization problem
- tentative fix for multiarch devel problems

* Mon Apr 28 2008 Daniel Veillard <veillard@redhat.com> 1.1.23-3.fc10
- and the previous patch was incomplete breaking the python bindings
  see 444317 and 444455

* Tue Apr 22 2008 Daniel Veillard <veillard@redhat.com> 1.1.23-2.fc10
- revert a key initialization patch from 1.1.23 which seems broken
  see rhbz#442097

* Tue Apr  8 2008 Daniel Veillard <veillard@redhat.com> 1.1.23-1.fc9
- upstream release 1.1.23
- bugfixes

* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.1.22-2
- Autorebuild for GCC 4.3

* Thu Aug 23 2007 Daniel Veillard <veillard@redhat.com> 1.1.22-1
- upstream release 1.1.22 see http://xmlsoft.org/XSLT/news.html

* Tue Jun 12 2007 Daniel Veillard <veillard@redhat.com> 1.1.21-1
- upstream release 1.1.21 see http://xmlsoft.org/XSLT/news.html

* Thu Feb 15 2007 Adam Jackson <ajax@redhat.com>
- Add dist tag to Release to fix 6->7 upgrades.

* Wed Jan 17 2007 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.20 see http://xmlsoft.org/XSLT/news.html

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 1.1.19-2
- rebuild against python 2.5

* Wed Nov 29 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.19 see http://xmlsoft.org/XSLT/news.html

* Thu Oct 26 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.18 see http://xmlsoft.org/XSLT/news.html

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.1.17-1.1
- rebuild

* Tue Jun  6 2006 Daniel Veillard <veillard@redhat.com>
- upstream release 1.1.17 see http://xmlsoft.org/XSLT/news.html
